@@ -680,7 +680,7 @@ class Webapp():
         """
         self.__webapp.SetKey(key, grid, grid_number,additional_key, wait_show, step)
 
-    def SetLateralMenu(self, menuitens):
+    def SetLateralMenu(self, menuitens, save_input=True, click_menu_functional=False):
         """
         Navigates through the lateral menu using provided menu path.
         e.g. "MenuItem1 > MenuItem2 > MenuItem3"
@@ -693,7 +693,7 @@ class Webapp():
         >>> # Calling the method:
         >>> oHelper.SetLateralMenu("Updates > Registers > Products > Groups")
         """
-        self.__webapp.SetLateralMenu(menuitens)
+        self.__webapp.SetLateralMenu(menuitens, save_input, click_menu_functional)
 
     def SetParameters(self):
         """
@@ -929,6 +929,25 @@ class Webapp():
         """
         self.__webapp.WaitShow(string)
 
+    def IfExists(self, string='', timeout=5):
+        """
+        Returns True if element exists in timeout or return False if not exist.
+
+        :param string: String that will hold the wait.
+        :type string: str
+        :param timeout: Timeout that wait before return.
+        :type timeout: str
+
+        Usage:
+
+        >>> # Calling the method:
+        >>> exist = oHelper.IfExists("Aviso", timeout=10)
+        >>> if oHelper.IfExists("Aviso", timeout=10):
+        >>>     print('Found!')
+        """
+
+        return self.__webapp.WaitShow(string, timeout, throw_error=False)
+
     def ClickTree(self, treepath, right_click=False, position=1):
         """
         Clicks on TreeView component.
@@ -1091,6 +1110,18 @@ class Webapp():
         >>> oHelper.ClickImage("img_name",double_click=True)
         """
         self.__webapp.ClickImage(img_name,double_click)
+    
+    def ClickMenuFunctional(self,menu_name,menu_option):
+        """Click on the functional menu.
+        :param menu_option: Item to be clicked.
+        :type menu_option: src
+
+        Usage:
+
+        >>> # Call the method:
+        >>> oHelper.ClickMenuFunctional("label","button") 
+        """
+        self.__webapp.ClickMenuFunctional(menu_name,menu_option)
 
     def ProgramScreen(self, initial_program=""):
         """
